@@ -1,5 +1,6 @@
 class a(object):
     def __init__(self):
-        self.name='小石'
+        self.name='小石的升级版'
+
     def print(self):
         print(self.name)
\ No newline at end of file
